<?php

namespace IMATHUZH\Qfq\Core\Renderer\Element\Bootstrap3;

use IMATHUZH\Qfq\Core\Helper\Support;

class Bootstrap3ButtonRenderer extends \IMATHUZH\Qfq\Core\Renderer\Element\ButtonRenderer
{
    /**
     * Generic function to create a button based on a spec array
     *
     * @param array $elementSpec    ['url'] -> link opened onclick of the button
     *                              ['buttonHtmlId'] -> HTML id of the button element
     *                              ['text'] -> HTML id of the button element
     *                              ['tooltip'] -> HTML id of the button element
     *                              ['icon'] -> name of the icon, e.g. "glyphicon-pencil"
     *                              ['disabled'] -> button disabled if this is set (no specific value needed)
     *                              ['class'] -> css class of the button
     *                              ['onChangeClass'] -> css class that is assigned to the button when form input changes
     *
     * @return string
     * @throws \CodeException
     */
    public function renderElement(array $elementSpec, string $renderMode = RENDER_MODE_HTML): string
    {
        $innerHTML = "";
        if (!isset($elementSpec['text'])) $elementSpec['text'] = "";
        if (!isset($elementSpec['icon']) || $elementSpec['icon'] === ""){
            $innerHTML = $elementSpec['text'];
        } else {
            $innerHTML = Support::wrapTag("<span " . Support::doAttribute('class', "glyphicon " . $elementSpec['icon']) . ">", $elementSpec['text']);
        }

        $attribute = "";
        if(isset($elementSpec['url'])) $attribute .= Support::doAttribute('href', $elementSpec['url']);
        if(isset($elementSpec['buttonHtmlId'])) $attribute .= Support::doAttribute('id', $elementSpec['buttonHtmlId']);
        if(isset($elementSpec['class'])) $attribute .= Support::doAttribute('class', $elementSpec['class']);
        if(isset($elementSpec['tooltip'])) $attribute .= Support::doAttribute('title', $elementSpec['tooltip']);
        if(isset($elementSpec['disabled'])) $attribute .= " disabled";
        if(isset($elementSpec['onChangeClass'])) $attribute .=  Support::doAttribute('data-class-on-change', $elementSpec['onChangeClass']);


        // disabled links do not show tooltips -> use a span
        $wrapTag = 'button';
        if(isset($elementSpec['disabled']) && $elementSpec['disabled'] != '') $wrapTag = 'span';
        if(isset($elementSpec['url'])) $wrapTag = 'a';
        if($wrapTag == 'button') $attribute .= Support::doAttribute('type', 'button');

        return Support::wrapTag("<$wrapTag $attribute>", $innerHTML);
    }
}